@@ -20,20 +20,19 @@
 #ifndef ADPLUG_XMMS_H
 #define ADPLUG_XMMS_H
 
-#include <glib.h>
 #include <audacious/plugin.h>
 
-gboolean adplug_init (void);
+bool_t adplug_init (void);
 void adplug_quit (void);
 void adplug_about (void);
 void adplug_config (void);
 void adplug_stop (InputPlayback * p);
-gboolean adplug_play (InputPlayback * p, const gchar * filename, VFSFile * file,
- gint start_time, gint stop_time, gboolean pause);
-void adplug_pause (InputPlayback * p, gboolean pause);
-void adplug_mseek (InputPlayback * p, gint time);
-void adplug_info_box (const gchar * filename);
-Tuple * adplug_get_tuple (const gchar * filename, VFSFile * file);
-gboolean adplug_is_our_fd (const gchar * filename, VFSFile * file);
+bool_t adplug_play (InputPlayback * p, const char * filename, VFSFile * file,
+ int start_time, int stop_time, bool_t pause);
+void adplug_pause (InputPlayback * p, bool_t pause);
+void adplug_mseek (InputPlayback * p, int time);
+void adplug_info_box (const char * filename);
+Tuple * adplug_get_tuple (const char * filename, VFSFile * file);
+bool_t adplug_is_our_fd (const char * filename, VFSFile * file);
 
 #endif
