@@ -1,8 +1,8 @@
+#include <audacious/i18n.h>
 #include <audacious/plugin.h>
 
 #include "adplug-xmms.h"
-
-static const gchar *fmts[] =
+static const char * fmts[] =
     { "a2m", "adl", "amd", "bam", "cff", "cmf", "d00", "dfm", "dmo", "dro",
       "dtm", "hsc", "hsp", "ins", "jbm", "ksm", "laa", "lds", "m", "mad",
       "mkj", "msc", "rad", "raw", "rix", "rol", "s3m", "sa2", "sat", "sci",
@@ -11,7 +11,8 @@ static const gchar *fmts[] =
 
 AUD_INPUT_PLUGIN
 (
-  .name = "AdPlug (AdLib Sound Player)",
+  .name = N_("AdPlug (AdLib Player)"),
+  .domain = PACKAGE,
   .init = adplug_init,
   .cleanup = adplug_quit,
   .play = adplug_play,
