@@ -1,6 +1,6 @@
 /*
  * ALSA Output Plugin for Audacious
- * Copyright 2009-2011 John Lindgren
+ * Copyright 2009-2012 John Lindgren
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -46,7 +46,6 @@
 #include <unistd.h>
 
 #include <alsa/asoundlib.h>
-#include <glib.h>
 
 #include <audacious/debug.h>
 #include <audacious/misc.h>
@@ -65,12 +64,11 @@ do { \
 
 #define CHECK_RECOVER(function, ...) \
 do { \
-    int error2; \
-    CHECK_VAL_RECOVER (error2, function, __VA_ARGS__); \
+    int CHECK_RECOVER_error; \
+    CHECK_VAL_RECOVER (CHECK_RECOVER_error, function, __VA_ARGS__); \
 } while (0)
 
 static snd_pcm_t * alsa_handle;
-static char alsa_initted;
 static pthread_mutex_t alsa_mutex = PTHREAD_MUTEX_INITIALIZER;
 static pthread_cond_t alsa_cond = PTHREAD_COND_INITIALIZER;
 
@@ -280,34 +278,17 @@ FAILED:
 
 int alsa_init (void)
 {
-    alsa_handle = NULL;
-    alsa_initted = 0;
+    AUDDBG ("Initialize.\n");
+    alsa_config_load ();
+    alsa_open_mixer ();
     return 1;
 }
 
-void alsa_soft_init (void)
-{
-    pthread_mutex_lock (& alsa_mutex);
-
-    if (! alsa_initted)
-    {
-        AUDDBG ("Initialize.\n");
-        alsa_config_load ();
-        alsa_open_mixer ();
-        alsa_initted = 1;
-    }
-
-    pthread_mutex_unlock (& alsa_mutex);
-}
-
 void alsa_cleanup (void)
 {
-    if (alsa_initted)
-    {
-        AUDDBG ("Cleanup.\n");
-        alsa_close_mixer ();
-        alsa_config_save ();
-    }
+    AUDDBG ("Cleanup.\n");
+    alsa_close_mixer ();
+    alsa_config_save ();
 }
 
 static int convert_aud_format (int aud_format)
@@ -335,7 +316,7 @@ static int convert_aud_format (int aud_format)
         {FMT_U32_BE, SND_PCM_FORMAT_U32_BE},
     };
 
-    for (int count = 0; count < G_N_ELEMENTS (table); count ++)
+    for (int count = 0; count < sizeof table / sizeof table[0]; count ++)
     {
         if (table[count].aud_format == aud_format)
             return table[count].format;
@@ -346,7 +327,6 @@ static int convert_aud_format (int aud_format)
 
 int alsa_open_audio (int aud_format, int rate, int channels)
 {
-    alsa_soft_init ();
     pthread_mutex_lock (& alsa_mutex);
 
     assert (alsa_handle == NULL);
@@ -544,22 +524,6 @@ FAILED:
     return;
 }
 
-void alsa_set_written_time (int time)
-{
-    AUDDBG ("Setting time counter to %d.\n", time);
-    pthread_mutex_lock (& alsa_mutex);
-    alsa_written = (int64_t) time * alsa_rate / 1000;
-    pthread_mutex_unlock (& alsa_mutex);
-}
-
-int alsa_written_time (void)
-{
-    pthread_mutex_lock (& alsa_mutex);
-    int time = (int64_t) alsa_written * 1000 / alsa_rate;
-    pthread_mutex_unlock (& alsa_mutex);
-    return time;
-}
-
 int alsa_output_time (void)
 {
     pthread_mutex_lock (& alsa_mutex);
@@ -678,7 +642,6 @@ void alsa_close_mixer (void)
 
 void alsa_get_volume (int * left, int * right)
 {
-    alsa_soft_init ();
     pthread_mutex_lock (& alsa_mutex);
 
     long left_l = 0, right_l = 0;
@@ -735,7 +698,6 @@ FAILED:
 
 void alsa_set_volume (int left, int right)
 {
-    alsa_soft_init ();
     pthread_mutex_lock (& alsa_mutex);
 
     if (alsa_mixer == NULL)
