@@ -49,6 +49,7 @@
 #include <audacious/playlist.h>
 #include <audacious/plugin.h>
 #include <audacious/preferences.h>
+#include <libaudcore/audstrings.h>
 #include <libaudcore/hook.h>
 #include <libaudgui/libaudgui.h>
 #include <libaudgui/libaudgui-gtk.h>
@@ -507,12 +508,18 @@ static Tuple * make_tuple (const char * filename, VFSFile * file)
     tuple_set_int (tuple, FIELD_LENGTH, NULL, calculate_track_length
      (trackinfo[trackno].startlsn, trackinfo[trackno].endlsn));
 
+    if (trackinfo[trackno].name[0])
+        tuple_set_str (tuple, FIELD_TITLE, NULL, trackinfo[trackno].name);
+    else
+    {
+        SPRINTF (title, _("Track %d"), trackno);
+        tuple_set_str (tuple, FIELD_TITLE, NULL, title);
+    }
+
     if (trackinfo[trackno].performer[0])
         tuple_set_str (tuple, FIELD_ARTIST, NULL, trackinfo[trackno].performer);
     if (trackinfo[0].name[0])
         tuple_set_str (tuple, FIELD_ALBUM, NULL, trackinfo[0].name);
-    if (trackinfo[trackno].name[0])
-        tuple_set_str (tuple, FIELD_TITLE, NULL, trackinfo[trackno].name);
     if (trackinfo[trackno].genre[0])
         tuple_set_str (tuple, FIELD_GENRE, NULL, trackinfo[trackno].genre);
 
@@ -679,12 +686,6 @@ static void scan_cd (void)
 #endif
             cdtext_was_available = TRUE;
         }
-        else
-        {
-            cdaudio_set_strinfo (&trackinfo[trackno], "", "", "");
-            snprintf (trackinfo[trackno].name, DEF_STRING_LEN,
-                      "Track %d", trackno);
-        }
     }
 
     if (!cdtext_was_available)
