@@ -6,14 +6,13 @@
 
 	// internal
 	#include <limits.h>
-	#if INT_MAX >= 0x7FFFFFFF
-		typedef int blip_long;
-		typedef unsigned int blip_ulong;
-	#else
-		typedef long blip_long;
-		typedef unsigned long blip_ulong;
+	#if INT_MAX < 0x7FFFFFFF
+		#error "int must be at least 32 bits"
 	#endif
 
+	typedef int blip_long;
+	typedef unsigned blip_ulong;
+
 // Time unit at source clock rate
 typedef blip_long blip_time_t;
 
@@ -24,66 +23,66 @@ enum { blip_sample_max = 32767 };
 class Blip_Buffer {
 public:
 	typedef const char* blargg_err_t;
-	
+
 	// Set output sample rate and buffer length in milliseconds (1/1000 sec, defaults
 	// to 1/4 second), then clear buffer. Returns NULL on success, otherwise if there
 	// isn't enough memory, returns error without affecting current buffer setup.
 	blargg_err_t set_sample_rate( long samples_per_sec, int msec_length = 1000 / 4 );
-	
+
 	// Set number of source time units per second
 	void clock_rate( long );
-	
+
 	// End current time frame of specified duration and make its samples available
 	// (along with any still-unread samples) for reading with read_samples(). Begins
 	// a new time frame at the end of the current frame.
 	void end_frame( blip_time_t time );
-	
+
 	// Read at most 'max_samples' out of buffer into 'dest', removing them from from
 	// the buffer. Returns number of samples actually read and removed. If stereo is
 	// true, increments 'dest' one extra time after writing each sample, to allow
 	// easy interleving of two channels into a stereo output buffer.
 	long read_samples( blip_sample_t* dest, long max_samples, int stereo = 0 );
-	
+
 // Additional optional features
 
 	// Current output sample rate
 	long sample_rate() const;
-	
+
 	// Length of buffer, in milliseconds
 	int length() const;
-	
+
 	// Number of source time units per second
 	long clock_rate() const;
-	
+
 	// Set frequency high-pass filter frequency, where higher values reduce bass more
 	void bass_freq( int frequency );
-	
+
 	// Number of samples delay from synthesis to samples read out
 	int output_latency() const;
-	
+
 	// Remove all available samples and clear buffer to silence. If 'entire_buffer' is
 	// false, just clears out any samples waiting rather than the entire buffer.
 	void clear( int entire_buffer = 1 );
-	
+
 	// Number of samples available for reading with read_samples()
 	long samples_avail() const;
-	
+
 	// Remove 'count' samples from those waiting to be read
 	void remove_samples( long count );
-	
+
 // Experimental features
-	
+
 	// Count number of clocks needed until 'count' samples will be available.
 	// If buffer can't even hold 'count' samples, returns number of clocks until
 	// buffer becomes full.
 	blip_time_t count_clocks( long count ) const;
-	
+
 	// Number of raw samples that can be mixed within frame of specified duration.
 	long count_samples( blip_time_t duration ) const;
-	
+
 	// Mix 'count' samples from 'buf' into buffer.
 	void mix_samples( blip_sample_t const* buf, long count );
-	
+
 	// not documented yet
 	void set_modified() { modified_ = 1; }
 	int clear_modified() { int b = modified_; modified_ = 0; return b; }
@@ -95,7 +94,7 @@ public:
 public:
 	Blip_Buffer();
 	~Blip_Buffer();
-	
+
 	// Deprecated
 	typedef blip_resampled_time_t resampled_time_t;
 	blargg_err_t sample_rate( long r ) { return set_sample_rate( r ); }
@@ -121,8 +120,6 @@ private:
 	friend class Blip_Reader;
 };
 
-#include "config.h"
-
 // Number of bits in resample ratio fraction. Higher values give a more accurate ratio
 // but reduce maximum buffer size.
 #ifndef BLIP_BUFFER_ACCURACY
@@ -146,24 +143,24 @@ private:
 	int const blip_buffer_extra_ = blip_widest_impulse_ + 2;
 	int const blip_res = 1 << BLIP_PHASE_BITS;
 	class blip_eq_t;
-	
+
 	class Blip_Synth_Fast_ {
 	public:
 		Blip_Buffer* buf;
 		int last_amp;
 		int delta_factor;
-		
+
 		void volume_unit( double );
 		Blip_Synth_Fast_();
 		void treble_eq( blip_eq_t const& ) { }
 	};
-	
+
 	class Blip_Synth_ {
 	public:
 		Blip_Buffer* buf;
 		int last_amp;
 		int delta_factor;
-		
+
 		void volume_unit( double );
 		Blip_Synth_( short* impulses, int width );
 		void treble_eq( blip_eq_t const& );
@@ -189,14 +186,14 @@ class Blip_Synth {
 public:
 	// Set overall volume of waveform
 	void volume( double v ) { impl.volume_unit( v * (1.0 / (range < 0 ? -range : range)) ); }
-	
+
 	// Configure low-pass filter (see blip_buffer.txt)
 	void treble_eq( blip_eq_t const& eq )       { impl.treble_eq( eq ); }
-	
+
 	// Get/set Blip_Buffer used for output
 	Blip_Buffer* output() const                 { return impl.buf; }
 	void output( Blip_Buffer* b )               { impl.buf = b; impl.last_amp = 0; }
-	
+
 	// Update amplitude of waveform at given time. Using this requires a separate
 	// Blip_Synth for each waveform.
 	void update( blip_time_t time, int amplitude );
@@ -208,10 +205,10 @@ public:
 	// The actual change in amplitude is delta * (volume / range)
 	void offset( blip_time_t, int delta, Blip_Buffer* ) const;
 	void offset( blip_time_t t, int delta ) const { offset( t, delta, impl.buf ); }
-	
+
 	// Works directly in terms of fractional output samples. Contact author for more info.
 	void offset_resampled( blip_resampled_time_t, int delta, Blip_Buffer* ) const;
-	
+
 	// Same as offset(), except code is inlined for higher performance
 	void offset_inline( blip_time_t t, int delta, Blip_Buffer* buf ) const {
 		offset_resampled( t * buf->factor_ + buf->offset_, delta, buf );
@@ -219,7 +216,7 @@ public:
 	void offset_inline( blip_time_t t, int delta ) const {
 		offset_resampled( t * impl.buf->factor_ + impl.buf->offset_, delta, impl.buf );
 	}
-	
+
 private:
 #if BLIP_BUFFER_FAST
 	Blip_Synth_Fast_ impl;
@@ -238,10 +235,10 @@ public:
 	// Logarithmic rolloff to treble dB at half sampling rate. Negative values reduce
 	// treble, small positive values (0 to 5.0) increase treble.
 	blip_eq_t( double treble_db = 0 );
-	
+
 	// See blip_buffer.txt
 	blip_eq_t( double treble, long rolloff_freq, long sample_rate, long cutoff_freq = 0 );
-	
+
 private:
 	double treble;
 	long rolloff_freq;
@@ -262,7 +259,7 @@ public:
 	blargg_err_t set_sample_rate( long samples_per_sec, int msec_length );
 	blip_time_t count_clocks( long count ) const;
 	void mix_samples( blip_sample_t const* buf, long count );
-	
+
 	Silent_Blip_Buffer();
 };
 
@@ -322,7 +319,7 @@ public:
 	blip_long read_raw() const      { return accum; }
 	void next( int bass_shift = 9 )         { accum += *buf++ - (accum >> bass_shift); }
 	void end( Blip_Buffer& b )              { b.reader_accum_ = accum; }
-	
+
 private:
 	const Blip_Buffer::buf_t_* buf;
 	blip_long accum;
@@ -345,14 +342,14 @@ inline void Blip_Synth<quality,range>::offset_resampled( blip_resampled_time_t t
 
 #if BLIP_BUFFER_FAST
 	blip_long left = buf [0] + delta;
-	
+
 	// Kind of crappy, but doing shift after multiply results in overflow.
 	// Alternate way of delaying multiply by delta_factor results in worse
 	// sub-sample resolution.
 	blip_long right = (delta >> BLIP_PHASE_BITS) * phase;
 	left  -= right;
 	right += buf [1];
-	
+
 	buf [0] = left;
 	buf [1] = right;
 #else
@@ -360,17 +357,17 @@ inline void Blip_Synth<quality,range>::offset_resampled( blip_resampled_time_t t
 	int const fwd = (blip_widest_impulse_ - quality) / 2;
 	int const rev = fwd + quality - 2;
 	int const mid = quality / 2 - 1;
-	
+
 	imp_t const* BLIP_RESTRICT imp = impulses + blip_res - phase;
-	
+
 	#if defined (_M_IX86) || defined (_M_IA64) || defined (__i486__) || \
 			defined (__x86_64__) || defined (__ia64__) || defined (__i386__)
-	
+
 	// straight forward implementation resulted in better code on GCC for x86
-	
+
 	#define ADD_IMP( out, in ) \
 		buf [out] += (blip_long) imp [blip_res * (in)] * delta
-	
+
 	#define BLIP_FWD( i ) {\
 		ADD_IMP( fwd     + i, i     );\
 		ADD_IMP( fwd + 1 + i, i + 1 );\
@@ -391,14 +388,14 @@ inline void Blip_Synth<quality,range>::offset_resampled( blip_resampled_time_t t
 		if ( quality > 12 ) BLIP_REV( 6 )
 		if ( quality > 8  ) BLIP_REV( 4 )
 		BLIP_REV( 2 )
-		
+
 		ADD_IMP( rev    , 1 );
 		ADD_IMP( rev + 1, 0 );
-		
+
 	#else
-	
+
 	// for RISC processors, help compiler by reading ahead of writes
-	
+
 	#define BLIP_FWD( i ) {\
 		blip_long t0 =                       i0 * delta + buf [fwd     + i];\
 		blip_long t1 = imp [blip_res * (i + 1)] * delta + buf [fwd + 1 + i];\
@@ -413,7 +410,7 @@ inline void Blip_Synth<quality,range>::offset_resampled( blip_resampled_time_t t
 		buf [rev     - r] = t0;\
 		buf [rev + 1 - r] = t1;\
 	}
-		
+
 		blip_long i0 = *imp;
 		BLIP_FWD( 0 )
 		if ( quality > 8  ) BLIP_FWD( 2 )
@@ -429,13 +426,13 @@ inline void Blip_Synth<quality,range>::offset_resampled( blip_resampled_time_t t
 		if ( quality > 12 ) BLIP_REV( 6 )
 		if ( quality > 8  ) BLIP_REV( 4 )
 		BLIP_REV( 2 )
-		
+
 		blip_long t0 =   i0 * delta + buf [rev    ];
 		blip_long t1 = *imp * delta + buf [rev + 1];
 		buf [rev    ] = t0;
 		buf [rev + 1] = t1;
 	#endif
-	
+
 #endif
 }
 
