@@ -50,20 +50,18 @@ void Hes_Cpu::reset()
 {
 	check( state == &state_ );
 	state = &state_;
-	
+
 	state_.time = 0;
 	state_.base = 0;
 	irq_time_   = future_hes_time;
 	end_time_   = future_hes_time;
-	
+
 	r.status = st_i;
 	r.sp     = 0;
 	r.pc     = 0;
 	r.a      = 0;
 	r.x      = 0;
 	r.y      = 0;
-	
-	blargg_verify_byte_order();
 }
 
 void Hes_Cpu::set_mmr( int reg, int bank )
@@ -101,7 +99,7 @@ bool Hes_Cpu::run( hes_time_t end_time )
 	this->state = &s;
 	// even on x86, using s.time in place of s_time was slower
 	fint16 s_time = s.time;
-	
+
 	// registers
 	fuint16 pc = r.pc;
 	fuint8 a = r.a;
@@ -109,9 +107,9 @@ bool Hes_Cpu::run( hes_time_t end_time )
 	fuint8 y = r.y;
 	fuint16 sp;
 	SET_SP( r.sp );
-	
+
 	#define IS_NEG (nz & 0x8080)
-	
+
 	#define CALC_STATUS( out ) do {\
 		out = status & (st_v | st_d | st_i);\
 		out |= ((nz >> 8) | nz) & st_n;\
@@ -125,7 +123,7 @@ bool Hes_Cpu::run( hes_time_t end_time )
 		c = nz;\
 		nz |= ~in & st_z;\
 	} while ( 0 )
-	
+
 	fuint8 status;
 	fuint16 c;  // carry set if (c & 0x100) != 0
 	fuint16 nz; // Z set if (nz & 0xFF) == 0, N set if (nz & 0x8080) != 0
@@ -133,12 +131,12 @@ bool Hes_Cpu::run( hes_time_t end_time )
 		fuint8 temp = r.status;
 		SET_STATUS( temp );
 	}
-	
+
 	goto loop;
 branch_not_taken:
 	s_time -= 2;
 loop:
-	
+
 	#ifndef NDEBUG
 	{
 		hes_time_t correct = end_time_;
@@ -157,10 +155,10 @@ loop:
 	check( (unsigned) GET_SP() < 0x100 );
 	check( (unsigned) a < 0x100 );
 	check( (unsigned) x < 0x100 );
-	
+
 	uint8_t const* instr = s.code_map [pc >> page_shift];
 	fuint8 opcode;
-	
+
 	// TODO: eliminate this special case
 	#if BLARGG_NONPORTABLE
 		opcode = instr [pc];
@@ -171,7 +169,7 @@ loop:
 		opcode = *instr++;
 		pc++;
 	#endif
-	
+
 	// TODO: each reference lists slightly different timing values, ugh
 	static uint8_t const clock_table [256] =
 	{// 0 1 2  3 4 5 6 7 8 9 A B C D E F
@@ -192,21 +190,21 @@ loop:
 		2,7,2,17,4,4,6,7,2,2,2,2,5,5,7,6,// E
 		4,7,7,17,2,4,6,7,2,5,4,2,2,5,7,6 // F
 	}; // 0x00 was 8
-	
+
 	fuint16 data;
 	data = clock_table [opcode];
 	if ( (s_time += data) >= 0 )
 		goto possibly_out_of_time;
 almost_out_of_time:
-	
+
 	data = *instr;
-	
+
 	#ifdef HES_CPU_LOG_H
 		log_cpu( "new", pc - 1, opcode, instr [0], instr [1], instr [2],
 				instr [3], instr [4], instr [5] );
 		//log_opcode( opcode );
 	#endif
-	
+
 	switch ( opcode )
 	{
 possibly_out_of_time:
@@ -230,41 +228,41 @@ possibly_out_of_time:
 // TODO: more efficient way to handle negative branch that wraps PC around
 #define BRANCH( cond )\
 {\
-	fint16 offset = (BOOST::int8_t) data;\
+	fint16 offset = (int8_t) data;\
 	pc++;\
 	if ( !(cond) ) goto branch_not_taken;\
-	pc = BOOST::uint16_t (pc + offset);\
+	pc = uint16_t (pc + offset);\
 	goto loop;\
 }
 
 	case 0xF0: // BEQ
 		BRANCH( !((uint8_t) nz) );
-	
+
 	case 0xD0: // BNE
 		BRANCH( (uint8_t) nz );
-	
+
 	case 0x10: // BPL
 		BRANCH( !IS_NEG );
-	
+
 	case 0x90: // BCC
 		BRANCH( !(c & 0x100) )
-	
+
 	case 0x30: // BMI
 		BRANCH( IS_NEG )
-	
+
 	case 0x50: // BVC
 		BRANCH( !(status & st_v) )
-	
+
 	case 0x70: // BVS
 		BRANCH( status & st_v )
-	
+
 	case 0xB0: // BCS
 		BRANCH( c & 0x100 )
-	
+
 	case 0x80: // BRA
 	branch_taken:
 		BRANCH( true );
-	
+
 	case 0xFF:
 		if ( pc == idle_addr + 1 )
 			goto idle_done;
@@ -289,11 +287,11 @@ possibly_out_of_time:
 		data = GET_MSB();
 		BRANCH( t & (1 << (opcode >> 4)) )
 	}
-	
+
 	case 0x4C: // JMP abs
 		pc = GET_ADDR();
 		goto loop;
-	
+
 	case 0x7C: // JMP (ind+X)
 		data += x;
 	case 0x6C:{// JMP (ind)
@@ -301,7 +299,7 @@ possibly_out_of_time:
 		pc = GET_LE16( &READ_PROG( data ) );
 		goto loop;
 	}
-	
+
 // Subroutine
 
 	case 0x44: // BSR
@@ -309,7 +307,7 @@ possibly_out_of_time:
 		sp = (sp - 2) | 0x100;
 		WRITE_LOW( sp, pc );
 		goto branch_taken;
-	
+
 	case 0x20: { // JSR
 		fuint16 temp = pc + 1;
 		pc = GET_ADDR();
@@ -318,16 +316,16 @@ possibly_out_of_time:
 		WRITE_LOW( sp, temp );
 		goto loop;
 	}
-	
+
 	case 0x60: // RTS
 		pc = 0x100 * READ_LOW( 0x100 | (sp - 0xFF) );
 		pc += 1 + READ_LOW( sp );
 		sp = (sp - 0xFE) | 0x100;
 		goto loop;
-	
+
 	case 0x00: // BRK
 		goto handle_brk;
-	
+
 // Common
 
 	case 0xBD:{// LDA abs,X
@@ -338,21 +336,21 @@ possibly_out_of_time:
 		a = nz;
 		goto loop;
 	}
-	
+
 	case 0x9D:{// STA abs,X
 		fuint16 addr = GET_ADDR() + x;
 		pc += 2;
 		CPU_WRITE_FAST( this, addr, a, TIME );
 		goto loop;
 	}
-	
+
 	case 0x95: // STA zp,x
 		data = uint8_t (data + x);
 	case 0x85: // STA zp
 		pc++;
 		WRITE_LOW( data, a );
 		goto loop;
-	
+
 	case 0xAE:{// LDX abs
 		fuint16 addr = GET_ADDR();
 		pc += 2;
@@ -360,14 +358,14 @@ possibly_out_of_time:
 		x = nz;
 		goto loop;
 	}
-	
+
 	case 0xA5: // LDA zp
 		a = nz = READ_LOW( data );
 		pc++;
 		goto loop;
-	
+
 // Load/store
-	
+
 	{
 		fuint16 addr;
 	case 0x91: // STA (ind),Y
@@ -375,7 +373,7 @@ possibly_out_of_time:
 		addr += READ_LOW( data ) + y;
 		pc++;
 		goto sta_ptr;
-	
+
 	case 0x81: // STA (ind,X)
 		data = uint8_t (data + x);
 	case 0x92: // STA (ind)
@@ -383,7 +381,7 @@ possibly_out_of_time:
 		addr += READ_LOW( data );
 		pc++;
 		goto sta_ptr;
-	
+
 	case 0x99: // STA abs,Y
 		data += y;
 	case 0x8D: // STA abs
@@ -393,7 +391,7 @@ possibly_out_of_time:
 		CPU_WRITE_FAST( this, addr, a, TIME );
 		goto loop;
 	}
-	
+
 	{
 		fuint16 addr;
 	case 0xA1: // LDA (ind,X)
@@ -403,14 +401,14 @@ possibly_out_of_time:
 		addr += READ_LOW( data );
 		pc++;
 		goto a_nz_read_addr;
-	
+
 	case 0xB1:// LDA (ind),Y
 		addr = READ_LOW( data ) + y;
 		PAGE_CROSS_PENALTY( addr );
 		addr += 0x100 * READ_LOW( (uint8_t) (data + 1) );
 		pc++;
 		goto a_nz_read_addr;
-	
+
 	case 0xB9: // LDA abs,Y
 		data += y;
 		PAGE_CROSS_PENALTY( data );
@@ -432,12 +430,12 @@ possibly_out_of_time:
 		CACHE_TIME();
 		goto loop;
 	}
-	
+
 	case 0xB5: // LDA zp,x
 		a = nz = READ_LOW( uint8_t (data + x) );
 		pc++;
 		goto loop;
-	
+
 	case 0xA9: // LDA #imm
 		pc++;
 		a  = data;
@@ -470,14 +468,14 @@ possibly_out_of_time:
 			goto loop; // Z should be clear, and nz must be non-zero if nz & a is
 		nz <<= 8; // set Z flag without affecting N flag
 		goto loop;
-		
+
 	{
 		fuint16 addr;
-		
+
 	case 0xB3: // TST abs,x
 		addr = GET_MSB() + x;
 		goto tst_abs;
-	
+
 	case 0x93: // TST abs
 		addr = GET_MSB();
 	tst_abs:
@@ -488,11 +486,11 @@ possibly_out_of_time:
 		CACHE_TIME();
 		goto tst_common;
 	}
-	
+
 	case 0xA3: // TST zp,x
 		nz = READ_LOW( uint8_t (GET_MSB() + x) );
 		goto tst_common;
-	
+
 	case 0x83: // TST zp
 		nz = READ_LOW( GET_MSB() );
 	tst_common:
@@ -503,7 +501,7 @@ possibly_out_of_time:
 			goto loop; // Z should be clear, and nz must be non-zero if nz & data is
 		nz <<= 8; // set Z flag without affecting N flag
 		goto loop;
-	
+
 	{
 		fuint16 addr;
 	case 0x0C: // TSB abs
@@ -511,7 +509,7 @@ possibly_out_of_time:
 		addr = GET_ADDR();
 		pc++;
 		goto txb_addr;
-	
+
 	// TODO: everyone lists different behaviors for the status flags, ugh
 	case 0x04: // TSB zp
 	case 0x14: // TRB zp
@@ -528,7 +526,7 @@ possibly_out_of_time:
 		CACHE_TIME();
 		goto loop;
 	}
-	
+
 	case 0x07: // RMBn
 	case 0x17:
 	case 0x27:
@@ -540,7 +538,7 @@ possibly_out_of_time:
 		pc++;
 		READ_LOW( data ) &= ~(1 << (opcode >> 4));
 		goto loop;
-	
+
 	case 0x87: // SMBn
 	case 0x97:
 	case 0xA7:
@@ -552,9 +550,9 @@ possibly_out_of_time:
 		pc++;
 		READ_LOW( data ) |= 1 << ((opcode >> 4) - 8);
 		goto loop;
-	
+
 // Load/store
-	
+
 	case 0x9E: // STZ abs,x
 		data += x;
 	case 0x9C: // STZ abs
@@ -564,28 +562,28 @@ possibly_out_of_time:
 		WRITE( data, 0 );
 		CACHE_TIME();
 		goto loop;
-	
+
 	case 0x74: // STZ zp,x
 		data = uint8_t (data + x);
 	case 0x64: // STZ zp
 		pc++;
 		WRITE_LOW( data, 0 );
 		goto loop;
-	
+
 	case 0x94: // STY zp,x
 		data = uint8_t (data + x);
 	case 0x84: // STY zp
 		pc++;
 		WRITE_LOW( data, y );
 		goto loop;
-	
+
 	case 0x96: // STX zp,y
 		data = uint8_t (data + y);
 	case 0x86: // STX zp
 		pc++;
 		WRITE_LOW( data, x );
 		goto loop;
-	
+
 	case 0xB6: // LDX zp,y
 		data = uint8_t (data + y);
 	case 0xA6: // LDX zp
@@ -595,7 +593,7 @@ possibly_out_of_time:
 		x = data;
 		nz = data;
 		goto loop;
-	
+
 	case 0xB4: // LDY zp,x
 		data = uint8_t (data + x);
 	case 0xA4: // LDY zp
@@ -605,7 +603,7 @@ possibly_out_of_time:
 		y = data;
 		nz = data;
 		goto loop;
-	
+
 	case 0xBC: // LDY abs,X
 		data += x;
 		PAGE_CROSS_PENALTY( data );
@@ -617,13 +615,13 @@ possibly_out_of_time:
 		CACHE_TIME();
 		goto loop;
 	}
-	
+
 	{
 		fuint8 temp;
 	case 0x8C: // STY abs
 		temp = y;
 		goto store_abs;
-	
+
 	case 0x8E: // STX abs
 		temp = x;
 	store_abs:
@@ -645,7 +643,7 @@ possibly_out_of_time:
 		CACHE_TIME();
 		goto cpx_data;
 	}
-	
+
 	case 0xE4: // CPX zp
 		data = READ_LOW( data );
 	case 0xE0: // CPX #imm
@@ -655,7 +653,7 @@ possibly_out_of_time:
 		c = ~nz;
 		nz &= 0xFF;
 		goto loop;
-	
+
 	case 0xCC:{// CPY abs
 		fuint16 addr = GET_ADDR();
 		pc++;
@@ -664,7 +662,7 @@ possibly_out_of_time:
 		CACHE_TIME();
 		goto cpy_data;
 	}
-	
+
 	case 0xC4: // CPY zp
 		data = READ_LOW( data );
 	case 0xC0: // CPY #imm
@@ -674,7 +672,7 @@ possibly_out_of_time:
 		c = ~nz;
 		nz &= 0xFF;
 		goto loop;
-	
+
 // Logical
 
 #define ARITH_ADDR_MODES( op )\
@@ -716,34 +714,34 @@ possibly_out_of_time:
 		c = ~nz;
 		nz &= 0xFF;
 		goto loop;
-	
+
 	ARITH_ADDR_MODES( 0x25 ) // AND
 		nz = (a &= data);
 		pc++;
 		goto loop;
-	
+
 	ARITH_ADDR_MODES( 0x45 ) // EOR
 		nz = (a ^= data);
 		pc++;
 		goto loop;
-	
+
 	ARITH_ADDR_MODES( 0x05 ) // ORA
 		nz = (a |= data);
 		pc++;
 		goto loop;
-	
+
 // Add/subtract
 
 	ARITH_ADDR_MODES( 0xE5 ) // SBC
 		data ^= 0xFF;
 		goto adc_imm;
-	
+
 	ARITH_ADDR_MODES( 0x65 ) // ADC
 	adc_imm: {
 		if ( status & st_d )
 			debug_printf( "Decimal mode not supported\n" );
 		fint16 carry = c >> 8 & 1;
-		fint16 ov = (a ^ 0x80) + carry + (BOOST::int8_t) data; // sign-extend
+		fint16 ov = (a ^ 0x80) + carry + (int8_t) data; // sign-extend
 		status &= ~st_v;
 		status |= ov >> 2 & 0x40;
 		c = nz = a + data + carry;
@@ -751,7 +749,7 @@ possibly_out_of_time:
 		a = (uint8_t) nz;
 		goto loop;
 	}
-	
+
 // Shift/rotate
 
 	case 0x4A: // LSR A
@@ -777,7 +775,7 @@ possibly_out_of_time:
 		a = (uint8_t) nz;
 		goto loop;
 	}
-	
+
 	case 0x5E: // LSR abs,X
 		data += x;
 	case 0x4E: // LSR abs
@@ -791,11 +789,11 @@ possibly_out_of_time:
 		c = temp << 8;
 		goto rotate_common;
 	}
-	
+
 	case 0x3E: // ROL abs,X
 		data += x;
 		goto rol_abs;
-	
+
 	case 0x1E: // ASL abs,X
 		data += x;
 	case 0x0E: // ASL abs
@@ -811,15 +809,15 @@ possibly_out_of_time:
 		WRITE( data, (uint8_t) nz );
 		CACHE_TIME();
 		goto loop;
-	
+
 	case 0x7E: // ROR abs,X
 		data += x;
 		goto ror_abs;
-	
+
 	case 0x76: // ROR zp,x
 		data = uint8_t (data + x);
 		goto ror_zp;
-	
+
 	case 0x56: // LSR zp,x
 		data = uint8_t (data + x);
 	case 0x46: // LSR zp
@@ -831,11 +829,11 @@ possibly_out_of_time:
 		c = temp << 8;
 		goto write_nz_zp;
 	}
-	
+
 	case 0x36: // ROL zp,x
 		data = uint8_t (data + x);
 		goto rol_zp;
-	
+
 	case 0x16: // ASL zp,x
 		data = uint8_t (data + x);
 	case 0x06: // ASL zp
@@ -845,35 +843,35 @@ possibly_out_of_time:
 		nz = c >> 8 & 1;
 		nz |= (c = READ_LOW( data ) << 1);
 		goto write_nz_zp;
-	
+
 // Increment/decrement
 
 #define INC_DEC_AXY( reg, n ) reg = uint8_t (nz = reg + n); goto loop;
 
 	case 0x1A: // INA
 		INC_DEC_AXY( a, +1 )
-	
+
 	case 0xE8: // INX
 		INC_DEC_AXY( x, +1 )
-	
+
 	case 0xC8: // INY
 		INC_DEC_AXY( y, +1 )
 
 	case 0x3A: // DEA
 		INC_DEC_AXY( a, -1 )
-	
+
 	case 0xCA: // DEX
 		INC_DEC_AXY( x, -1 )
-	
+
 	case 0x88: // DEY
 		INC_DEC_AXY( y, -1 )
-	
+
 	case 0xF6: // INC zp,x
 		data = uint8_t (data + x);
 	case 0xE6: // INC zp
 		nz = 1;
 		goto add_nz_zp;
-	
+
 	case 0xD6: // DEC zp,x
 		data = uint8_t (data + x);
 	case 0xC6: // DEC zp
@@ -884,21 +882,21 @@ possibly_out_of_time:
 		pc++;
 		WRITE_LOW( data, nz );
 		goto loop;
-	
+
 	case 0xFE: // INC abs,x
 		data = x + GET_ADDR();
 		goto inc_ptr;
-	
+
 	case 0xEE: // INC abs
 		data = GET_ADDR();
 	inc_ptr:
 		nz = 1;
 		goto inc_common;
-	
+
 	case 0xDE: // DEC abs,x
 		data = x + GET_ADDR();
 		goto dec_ptr;
-	
+
 	case 0xCE: // DEC abs
 		data = GET_ADDR();
 	dec_ptr:
@@ -910,24 +908,24 @@ possibly_out_of_time:
 		WRITE( data, (uint8_t) nz );
 		CACHE_TIME();
 		goto loop;
-		
+
 // Transfer
 
 	case 0xA8: // TAY
 		y  = a;
 		nz = a;
 		goto loop;
-	
+
 	case 0x98: // TYA
 		a  = y;
 		nz = y;
 		goto loop;
-	
+
 	case 0xAA: // TAX
 		x  = a;
 		nz = a;
 		goto loop;
-		
+
 	case 0x8A: // TXA
 		a  = x;
 		nz = x;
@@ -936,53 +934,53 @@ possibly_out_of_time:
 	case 0x9A: // TXS
 		SET_SP( x ); // verified (no flag change)
 		goto loop;
-	
+
 	case 0xBA: // TSX
 		x = nz = GET_SP();
 		goto loop;
-	
+
 	#define SWAP_REGS( r1, r2 ) {\
 		fuint8 t = r1;\
 		r1 = r2;\
 		r2 = t;\
 		goto loop;\
 	}
-	
+
 	case 0x02: // SXY
 		SWAP_REGS( x, y );
-	
+
 	case 0x22: // SAX
 		SWAP_REGS( a, x );
-	
+
 	case 0x42: // SAY
 		SWAP_REGS( a, y );
-	
+
 	case 0x62: // CLA
 		a = 0;
 		goto loop;
-	
+
 	case 0x82: // CLX
 		x = 0;
 		goto loop;
-	
+
 	case 0xC2: // CLY
 		y = 0;
 		goto loop;
-	
+
 // Stack
-	
+
 	case 0x48: // PHA
 		PUSH( a );
 		goto loop;
-		
+
 	case 0xDA: // PHX
 		PUSH( x );
 		goto loop;
-		
+
 	case 0x5A: // PHY
 		PUSH( y );
 		goto loop;
-		
+
 	case 0x40:{// RTI
 		fuint8 temp = READ_LOW( sp );
 		pc  = READ_LOW( 0x100 | (sp - 0xFF) );
@@ -1002,21 +1000,21 @@ possibly_out_of_time:
 		}
 		goto loop;
 	}
-	
+
 	#define POP()  READ_LOW( sp ); sp = (sp - 0xFF) | 0x100
-	
+
 	case 0x68: // PLA
 		a = nz = POP();
 		goto loop;
-	
+
 	case 0xFA: // PLX
 		x = nz = POP();
 		goto loop;
-	
+
 	case 0x7A: // PLY
 		y = nz = POP();
 		goto loop;
-	
+
 	case 0x28:{// PLP
 		fuint8 temp = POP();
 		fuint8 changed = status ^ temp;
@@ -1028,36 +1026,36 @@ possibly_out_of_time:
 		goto handle_cli;
 	}
 	#undef POP
-	
+
 	case 0x08: { // PHP
 		fuint8 temp;
 		CALC_STATUS( temp );
 		PUSH( temp | st_b );
 		goto loop;
 	}
-	
+
 // Flags
 
 	case 0x38: // SEC
 		c = (unsigned) ~0;
 		goto loop;
-	
+
 	case 0x18: // CLC
 		c = 0;
 		goto loop;
-		
+
 	case 0xB8: // CLV
 		status &= ~st_v;
 		goto loop;
-	
+
 	case 0xD8: // CLD
 		status &= ~st_d;
 		goto loop;
-	
+
 	case 0xF8: // SED
 		status |= st_d;
 		goto loop;
-	
+
 	case 0x58: // CLI
 		if ( !(status & st_i) )
 			goto loop;
@@ -1075,7 +1073,7 @@ possibly_out_of_time:
 		s_time += delta;
 		if ( s_time < 0 )
 			goto loop;
-		
+
 		if ( delta >= s_time + 1 )
 		{
 			// delayed irq until after next instruction
@@ -1088,7 +1086,7 @@ possibly_out_of_time:
 		debug_printf( "Delayed CLI not supported\n" ); // TODO: implement
 		goto loop;
 	}
-	
+
 	case 0x78: // SEI
 		if ( status & st_i )
 			goto loop;
@@ -1103,9 +1101,9 @@ possibly_out_of_time:
 		debug_printf( "Delayed SEI not supported\n" ); // TODO: implement
 		goto loop;
 	}
-	
+
 // Special
-	
+
 	case 0x53:{// TAM
 		fuint8 const bits = data; // avoid using data across function call
 		pc++;
@@ -1114,7 +1112,7 @@ possibly_out_of_time:
 				set_mmr( i, a );
 		goto loop;
 	}
-	
+
 	case 0x43:{// TMA
 		pc++;
 		byte const* in = mmr;
@@ -1127,7 +1125,7 @@ possibly_out_of_time:
 		while ( (data >>= 1) != 0 );
 		goto loop;
 	}
-	
+
 	case 0x03: // ST0
 	case 0x13: // ST1
 	case 0x23:{// ST2
@@ -1140,7 +1138,7 @@ possibly_out_of_time:
 		CACHE_TIME();
 		goto loop;
 	}
-	
+
 	case 0xEA: // NOP
 		goto loop;
 
@@ -1148,10 +1146,10 @@ possibly_out_of_time:
 		debug_printf( "CSL not supported\n" );
 		illegal_encountered = true;
 		goto loop;
-	
+
 	case 0xD4: // CSH
 		goto loop;
-	
+
 	case 0xF4: { // SET
 		//fuint16 operand = GET_MSB();
 		debug_printf( "SET not handled\n" );
@@ -1161,7 +1159,7 @@ possibly_out_of_time:
 		illegal_encountered = true;
 		goto loop;
 	}
-	
+
 // Block transfer
 
 	{
@@ -1169,11 +1167,11 @@ possibly_out_of_time:
 		fint16 in_inc;
 		fuint16 out_alt;
 		fint16 out_inc;
-		
+
 	case 0xE3: // TIA
 		in_alt  = 0;
 		goto bxfer_alt;
-	
+
 	case 0xF3: // TAI
 		in_alt  = 1;
 	bxfer_alt:
@@ -1181,17 +1179,17 @@ possibly_out_of_time:
 		out_alt = in_inc;
 		out_inc = in_alt;
 		goto bxfer;
-	
+
 	case 0xD3: // TIN
 		in_inc  = 1;
 		out_inc = 0;
 		goto bxfer_no_alt;
-	
+
 	case 0xC3: // TDD
 		in_inc  = -1;
 		out_inc = -1;
 		goto bxfer_no_alt;
-	
+
 	case 0x73: // TII
 		in_inc  = 1;
 		out_inc = 1;
@@ -1238,37 +1236,37 @@ possibly_out_of_time:
 		goto loop;
 	}
 	assert( false );
-	
+
 	int result_;
 handle_brk:
 	pc++;
 	result_ = 6;
-	
+
 interrupt:
 	{
 		s_time += 7;
-		
+
 		WRITE_LOW( 0x100 | (sp - 1), pc >> 8 );
 		WRITE_LOW( 0x100 | (sp - 2), pc );
 		pc = GET_LE16( &READ_PROG( 0xFFF0 ) + result_ );
-		
+
 		sp = (sp - 3) | 0x100;
 		fuint8 temp;
 		CALC_STATUS( temp );
 		if ( result_ == 6 )
 			temp |= st_b;
 		WRITE_LOW( sp, temp );
-		
+
 		status &= ~st_d;
 		status |= st_i;
 		this->r.status = status; // update externally-visible I flag
-		
+
 		blargg_long delta = s.base - end_time_;
 		s.base = end_time_;
 		s_time += delta;
 		goto loop;
 	}
-	
+
 idle_done:
 	s_time = 0;
 out_of_time:
@@ -1280,24 +1278,24 @@ out_of_time:
 		goto interrupt;
 	if ( s_time < 0 )
 		goto loop;
-	
+
 	s.time = s_time;
-	
+
 	r.pc = pc;
 	r.sp = GET_SP();
 	r.a = a;
 	r.x = x;
 	r.y = y;
-	
+
 	{
 		fuint8 temp;
 		CALC_STATUS( temp );
 		r.status = temp;
 	}
-	
+
 	this->state_ = s;
 	this->state = &this->state_;
-	
+
 	return illegal_encountered;
 }
 
