@@ -16,11 +16,11 @@ void Sap_Emu::cpu_write( sap_addr_t addr, int data )
 	#define CPU_READ( cpu, addr, time )     READ_LOW( addr )
 #else
 	#define CPU_READ( cpu, addr, time )     STATIC_CAST(Sap_Emu&,*cpu).cpu_read( addr )
-	
+
 	int Sap_Emu::cpu_read( sap_addr_t addr )
 	{
 		if ( (addr & 0xF900) == 0xD000 )
-			dprintf( "Unmapped read $%04X\n", addr );
+			debug_printf( "Unmapped read $%04X\n", addr );
 		return mem.ram [addr];
 	}
 #endif
