@@ -23,8 +23,6 @@
 #ifndef FILEWRITER_H
 #define FILEWRITER_H
 
-#include "config.h"
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>
@@ -53,7 +51,7 @@ typedef struct _FileWriter
     gint (*open)(void);
     void (*write)(void *ptr, gint length);
     void (*close)(void);
-    gint format_required;
+    int (*format_required)(int fmt);
 } FileWriter;
 
 #endif
