@@ -234,7 +234,7 @@ static const struct MenuItem playlist_items[] = {
  {N_("_Refresh"), GTK_STOCK_REFRESH, GDK_KEY_F5, .func = pl_refresh},
  {.sep = TRUE},
  {N_("_Sort"), GTK_STOCK_SORT_ASCENDING, .items = sort_items, G_N_ELEMENTS (sort_items)},
- {N_("Sort S_elected"), GTK_STOCK_SORT_ASCENDING, .items = sort_selected_items, G_N_ELEMENTS (sort_selected_items)},
+ {N_("Sort Se_lected"), GTK_STOCK_SORT_ASCENDING, .items = sort_selected_items, G_N_ELEMENTS (sort_selected_items)},
  {N_("Remove _Duplicates"), GTK_STOCK_REMOVE, .items = dupe_items, G_N_ELEMENTS (dupe_items)},
  {N_("Remove _Unavailable Files"), GTK_STOCK_REMOVE, .func = pl_remove_failed},
  {.sep = TRUE},
