@@ -13,7 +13,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 #ifndef DEBUG_H
 #define DEBUG_H
@@ -22,15 +22,13 @@
 
 #define _ENTER _DEBUG("enter")
 #define _LEAVE _DEBUG("leave"); return
-#define _MESSAGE(tag, string, ...) do { fprintf(stderr, "%s: neon: %s:%d (%s): " string "\n", \
-    tag, __FILE__, __LINE__, __func__, ##__VA_ARGS__); } while(0)
 
-#define _ERROR(...) _MESSAGE("ERROR", __VA_ARGS__)
+#define _ERROR(...) do { printf ("neon: " __VA_ARGS__); putchar ('\n'); } while (0)
 
 #ifdef NEON_DEBUG
-#define _DEBUG(...) _MESSAGE("DEBUG",  __VA_ARGS__)
+#define _DEBUG _ERROR
 #else
-#define _DEBUG(...) {}
+#define _DEBUG(...)
 #endif
 
 #endif
