@@ -18,7 +18,7 @@ void xs_md5_append (xs_md5state_t * state, const void * data, int length)
 
 void xs_md5_finish (xs_md5state_t * state, xs_md5hash_t hash)
 {
-    gsize length = XS_MD5HASH_LENGTH;
+    size_t length = XS_MD5HASH_LENGTH;
     g_checksum_get_digest (state->priv, hash, & length);
     g_checksum_free (state->priv);
     state->priv = NULL;
