@@ -27,7 +27,6 @@
 #include <libaudgui/libaudgui.h>
 #include <libaudgui/libaudgui-gtk.h>
 
-#include "config.h"
 #include "plugin.h"
 #include "skins_cfg.h"
 #include "ui_equalizer.h"
@@ -126,8 +125,6 @@ static gboolean skins_init (void)
     else
         mainwin_update_song_info ();
 
-    mainwin_show (config.player_visible);
-
     update_source = g_timeout_add (250, update_cb, NULL);
 
     return TRUE;
@@ -159,7 +156,7 @@ static void skins_cleanup (void)
 
 static gboolean ui_is_shown (void)
 {
-    return config.player_visible;
+    return gtk_widget_get_visible (mainwin);
 }
 
 static gboolean ui_is_focused (void)
