@@ -104,6 +104,12 @@ static void shuffle_toggled (void * data, void * user)
     check_set (toggleaction_group_others, "playback shuffle", shuffle);
 }
 
+static void no_advance_toggled (void * data, void * user)
+{
+    bool_t no_advance = aud_get_bool (NULL, "no_playlist_advance");
+    check_set (toggleaction_group_others, "playback no playlist advance", no_advance);
+}
+
 static void stop_after_song_toggled (void * hook_data, void * user_data)
 {
     mainwin_enable_status_message (FALSE);
@@ -197,8 +203,8 @@ static void make_log_graph (const gfloat * freq, gint bands, gint db_range, gint
     if (bands != last_bands)
     {
         xscale = g_realloc (xscale, sizeof (gfloat) * (bands + 1));
-        for (gint i = 0; i <= bands; i ++)
-            xscale[i] = powf (257, (gfloat) i / bands) - 1;
+        for (int i = 0; i <= bands; i ++)
+            xscale[i] = powf (256, (float) i / bands) - 0.5f;
 
         last_bands = bands;
     }
@@ -225,13 +231,13 @@ static void make_log_graph (const gfloat * freq, gint bands, gint db_range, gint
 
         /* fudge factor to make the graph have the same overall height as a
            12-band one no matter how many bands there are */
-        sum = sum * bands / 12;
+        sum *= (gfloat) bands / 12;
 
         /* convert to dB */
         gfloat val = 20 * log10f (sum);
 
         /* scale (-db_range, 0.0) to (0.0, int_range) */
-        val = (1.0 + val / db_range) * int_range;
+        val = (1 + val / db_range) * int_range;
 
         graph[i] = CLAMP (val, 0, int_range);
     }
@@ -285,6 +291,7 @@ ui_main_evlistener_init(void)
 
     hook_associate ("set repeat", repeat_toggled, NULL);
     hook_associate ("set shuffle", shuffle_toggled, NULL);
+    hook_associate ("set no_playlist_advance", no_advance_toggled, NULL);
     hook_associate ("set stop_after_current_song", stop_after_song_toggled, NULL);
 }
 
@@ -304,6 +311,7 @@ ui_main_evlistener_dissociate(void)
 
     hook_dissociate ("set repeat", repeat_toggled);
     hook_dissociate ("set shuffle", shuffle_toggled);
+    hook_dissociate ("set no_playlist_advance", no_advance_toggled);
     hook_dissociate ("set stop_after_current_song", stop_after_song_toggled);
 }
 
@@ -311,7 +319,7 @@ void start_stop_visual (gboolean exiting)
 {
     static char started = 0;
 
-    if (config.player_visible && config.vis_type != VIS_OFF && ! exiting)
+    if (config.vis_type != VIS_OFF && ! exiting && gtk_widget_get_visible (mainwin))
     {
         if (! started)
         {
