@@ -38,9 +38,9 @@
 #include <libaudgui/libaudgui.h>
 
 #include "actions-mainwin.h"
-#include "config.h"
 #include "dnd.h"
 #include "drag-handle.h"
+#include "plugin.h"
 #include "skins_cfg.h"
 #include "ui_main.h"
 #include "ui_manager.h"
@@ -57,12 +57,10 @@
 #define PLAYLISTWIN_HEIGHT_SNAP         29
 #define PLAYLISTWIN_SHADED_HEIGHT       MAINWIN_SHADED_HEIGHT
 
-gint active_playlist;
-gchar * active_title;
-glong active_length;
-GtkWidget * playlistwin, * playlistwin_list, * playlistwin_sinfo;
+gint active_playlist = -1, active_length = 0;
+gchar * active_title = NULL;
 
-static GMutex *resize_mutex = NULL;
+GtkWidget * playlistwin, * playlistwin_list, * playlistwin_sinfo;
 
 static GtkWidget *playlistwin_shade, *playlistwin_close;
 static GtkWidget *playlistwin_shaded_shade, *playlistwin_shaded_close;
@@ -175,9 +173,9 @@ playlistwin_shade_toggle(void)
 
 static void playlistwin_scroll (gboolean up)
 {
-    gint rows, first, focused;
+    gint rows, first;
 
-    ui_skinned_playlist_row_info (playlistwin_list, & rows, & first, & focused);
+    ui_skinned_playlist_row_info (playlistwin_list, & rows, & first);
     ui_skinned_playlist_scroll_to (playlistwin_list, first + (up ? -1 : 1) *
      rows / 3);
 }
@@ -431,8 +429,6 @@ static void playlistwin_resize (gint w, gint h)
     config.playlist_width = w = tx;
     config.playlist_height = h = ty;
 
-    g_mutex_lock(resize_mutex);
-
     ui_skinned_playlist_resize (playlistwin_list, w - 31, h - 58);
     window_move_widget (playlistwin, FALSE, playlistwin_slider, w - 15, 20);
     ui_skinned_playlist_slider_resize (playlistwin_slider, h - 58);
@@ -465,17 +461,12 @@ static void playlistwin_resize (gint w, gint h)
     window_move_widget (playlistwin, FALSE, button_sel, 68, h - 29);
     window_move_widget (playlistwin, FALSE, button_misc, 100, h - 29);
     window_move_widget (playlistwin, FALSE, button_list, w - 46, h - 29);
-
-    g_mutex_unlock(resize_mutex);
 }
 
 static void
 playlistwin_fileinfo(void)
 {
-    gint rows, first, focused;
-
-    ui_skinned_playlist_row_info (playlistwin_list, & rows, & first, & focused);
-    audgui_infowin_show (active_playlist, focused);
+    audgui_infowin_show (active_playlist, aud_playlist_get_focus (active_playlist));
 }
 
 static void
@@ -510,12 +501,6 @@ playlistwin_press(GtkWidget * widget,
     return TRUE;
 }
 
-static gboolean playlistwin_delete(GtkWidget *widget, void *data)
-{
-    aud_drct_quit ();
-    return TRUE;
-}
-
 void
 playlistwin_hide_timer(void)
 {
@@ -677,7 +662,7 @@ playlistwin_create_widgets(void)
 
     playlistwin_splay = button_new_small (10, 7);
     window_put_widget (playlistwin, FALSE, playlistwin_splay, w - 138, h - 16);
-    button_on_release (playlistwin_splay, (ButtonCB) mainwin_play_pushed);
+    button_on_release (playlistwin_splay, (ButtonCB) aud_drct_play);
 
     playlistwin_spause = button_new_small (10, 7);
     window_put_widget (playlistwin, FALSE, playlistwin_spause, w - 128, h - 16);
@@ -761,27 +746,18 @@ playlistwin_create_window(void)
                           GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
                           GDK_SCROLL_MASK | GDK_VISIBILITY_NOTIFY_MASK);
 
-    g_signal_connect(playlistwin, "delete_event",
-                     G_CALLBACK(playlistwin_delete), NULL);
-    g_signal_connect(playlistwin, "button_press_event",
-                     G_CALLBACK(playlistwin_press), NULL);
-    g_signal_connect(playlistwin, "scroll_event",
-                     G_CALLBACK(playlistwin_scrolled), NULL);
-
-    drag_dest_set(playlistwin);
+    g_signal_connect (playlistwin, "delete-event", (GCallback) handle_window_close, NULL);
+    g_signal_connect (playlistwin, "button-press-event", (GCallback) playlistwin_press, NULL);
+    g_signal_connect (playlistwin, "scroll-event", (GCallback) playlistwin_scrolled, NULL);
+    g_signal_connect (playlistwin, "key-press-event", (GCallback) mainwin_keypress, NULL);
 
+    drag_dest_set (playlistwin);
     drop_position = -1;
-    g_signal_connect ((GObject *) playlistwin, "drag-motion", (GCallback)
-     drag_motion, 0);
-    g_signal_connect ((GObject *) playlistwin, "drag-leave", (GCallback)
-     drag_leave, 0);
-    g_signal_connect ((GObject *) playlistwin, "drag-drop", (GCallback)
-     drag_drop, 0);
-    g_signal_connect ((GObject *) playlistwin, "drag-data-received", (GCallback)
-     drag_data_received, 0);
 
-    g_signal_connect ((GObject *) playlistwin, "key-press-event", (GCallback)
-     mainwin_keypress, 0);
+    g_signal_connect (playlistwin, "drag-motion", (GCallback) drag_motion, NULL);
+    g_signal_connect (playlistwin, "drag-leave", (GCallback) drag_leave, NULL);
+    g_signal_connect (playlistwin, "drag-drop", (GCallback) drag_drop, NULL);
+    g_signal_connect (playlistwin, "drag-data-received", (GCallback) drag_data_received, NULL);
 }
 
 static void get_title (void)
@@ -846,7 +822,6 @@ playlistwin_create(void)
     active_title = NULL;
     get_title ();
 
-    resize_mutex = g_mutex_new();
     playlistwin_create_window();
 
     playlistwin_create_widgets();
@@ -876,8 +851,6 @@ void playlistwin_unhook (void)
     hook_dissociate ("playlist update", update_cb);
     g_free (active_title);
     active_title = NULL;
-    g_mutex_free (resize_mutex);
-    resize_mutex = NULL;
 }
 
 static void playlistwin_real_show (gboolean show)
@@ -900,7 +873,7 @@ void playlistwin_show (char show)
     {
         config.playlist_visible = show;
         button_set_active (mainwin_pl, show);
-        playlistwin_real_show (config.player_visible && show);
+        playlistwin_real_show (show && gtk_widget_get_visible (mainwin));
     }
 }
 
@@ -911,11 +884,11 @@ void action_playlist_track_info(void)
 
 void action_queue_toggle (void)
 {
-    gint rows, first, focused, at;
+    gint focus = aud_playlist_get_focus (active_playlist);
+    if (focus == -1)
+        return;
 
-    ui_skinned_playlist_row_info (playlistwin_list, & rows, & first, & focused);
-    at = (focused == -1) ? -1 : aud_playlist_queue_find_entry (active_playlist,
-     focused);
+    gint at = aud_playlist_queue_find_entry (active_playlist, focus);
 
     if (at == -1)
         aud_playlist_queue_insert_selected (active_playlist, -1);
@@ -1072,13 +1045,12 @@ void action_playlist_paste (void)
 {
     GtkClipboard * clip = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
     gchar * list = gtk_clipboard_wait_for_text (clip);
-    gint rows, first, focused;
 
     if (list == NULL)
         return;
 
-    ui_skinned_playlist_row_info (playlistwin_list, & rows, & first, & focused);
-    audgui_urilist_insert (active_playlist, focused, list);
+    audgui_urilist_insert (active_playlist,
+     aud_playlist_get_focus (active_playlist), list);
     g_free (list);
 }
 
