@@ -38,7 +38,6 @@
 #include "ui_skinned_playlist_slider.h"
 
 #include <audacious/drct.h>
-#include <audacious/gtk-compat.h>
 #include <audacious/misc.h>
 #include <audacious/playlist.h>
 #include <libaudgui/libaudgui.h>
@@ -48,8 +47,8 @@ enum {DRAG_SELECT = 1, DRAG_MOVE};
 typedef struct {
     GtkWidget * slider;
     PangoFontDescription * font;
-    gint width, height, row_height, offset, rows, first, focused, scroll,
-     scroll_source, hover, drag;
+    gint width, height, row_height, offset, rows, first, scroll, scroll_source,
+     hover, drag;
     gint popup_pos, popup_source;
     gboolean popup_shown;
 } PlaylistData;
@@ -102,10 +101,11 @@ static gint adjust_position (PlaylistData * data, gboolean relative, gint
 
     if (relative)
     {
-        if (data->focused == -1)
+        gint focus = aud_playlist_get_focus (active_playlist);
+        if (focus == -1)
             return 0;
 
-        position += data->focused;
+        position += focus;
     }
 
     if (position < 0)
@@ -301,14 +301,13 @@ DRAW_FUNC_BEGIN (playlist_draw)
 
     /* focus rectangle */
 
-    if (data->focused >= data->first && data->focused <= data->first +
-     data->rows - 1)
+    gint focus = aud_playlist_get_focus (active_playlist);
+    if (focus >= data->first && focus <= data->first + data->rows - 1)
     {
         cairo_new_path (cr);
         cairo_set_line_width (cr, 1);
-        cairo_rectangle (cr, 0.5, data->offset + data->row_height *
-         (data->focused - data->first) + 0.5, data->width - 1, data->row_height
-         - 1);
+        cairo_rectangle (cr, 0.5, data->offset + data->row_height * (focus -
+         data->first) + 0.5, data->width - 1, data->row_height - 1);
         set_cairo_color (cr, active_skin->colors[SKIN_PLEDIT_NORMAL]);
         cairo_stroke (cr);
     }
@@ -359,7 +358,6 @@ GtkWidget * ui_skinned_playlist_new (gint width, gint height, const gchar * font
     PlaylistData * data = g_malloc0 (sizeof (PlaylistData));
     data->width = width;
     data->height = height;
-    data->focused = -1;
     data->hover = -1;
     data->popup_pos = -1;
     g_object_set_data ((GObject *) list, "playlistdata", data);
@@ -427,9 +425,6 @@ void ui_skinned_playlist_update (GtkWidget * list)
 
     calc_layout (data);
 
-    if (data->focused != -1)
-        data->focused = adjust_position (data, TRUE, 0);
-
     gtk_widget_queue_draw (list);
 
     if (data->slider != NULL)
@@ -451,15 +446,9 @@ static void select_single (PlaylistData * data, gboolean relative, gint position
     if (position == -1)
         return;
 
-    if (data->focused != -1)
-        aud_playlist_entry_set_selected (active_playlist, data->focused, FALSE);
-
-    if (aud_playlist_selected_count (active_playlist) > 0)
-        aud_playlist_select_all (active_playlist, FALSE);
-
+    aud_playlist_select_all (active_playlist, FALSE);
     aud_playlist_entry_set_selected (active_playlist, position, TRUE);
-
-    data->focused = position;
+    aud_playlist_set_focus (active_playlist, position);
     scroll_to (data, position);
 }
 
@@ -467,7 +456,7 @@ static void select_extend (PlaylistData * data, gboolean relative, gint position
 {
     position = adjust_position (data, relative, position);
 
-    if (position == -1 || position == data->focused)
+    if (position == -1)
         return;
 
     gint count = adjust_position (data, TRUE, 0);
@@ -478,8 +467,7 @@ static void select_extend (PlaylistData * data, gboolean relative, gint position
          ! aud_playlist_entry_get_selected (active_playlist, count + sign));
 
     aud_playlist_entry_set_selected (active_playlist, position, TRUE);
-
-    data->focused = position;
+    aud_playlist_set_focus (active_playlist, position);
     scroll_to (data, position);
 }
 
@@ -490,7 +478,7 @@ static void select_slide (PlaylistData * data, gboolean relative, gint position)
     if (position == -1)
         return;
 
-    data->focused = position;
+    aud_playlist_set_focus (active_playlist, position);
     scroll_to (data, position);
 }
 
@@ -503,40 +491,34 @@ static void select_toggle (PlaylistData * data, gboolean relative, gint position
 
     aud_playlist_entry_set_selected (active_playlist, position,
      ! aud_playlist_entry_get_selected (active_playlist, position));
-
-    data->focused = position;
+    aud_playlist_set_focus (active_playlist, position);
     scroll_to (data, position);
 }
 
 static void select_move (PlaylistData * data, gboolean relative, gint position)
 {
+    gint focus = aud_playlist_get_focus (active_playlist);
     position = adjust_position (data, relative, position);
 
-    if (data->focused == -1 || position == -1 || position == data->focused)
+    if (focus == -1 || position == -1 || position == focus)
         return;
 
-    data->focused += aud_playlist_shift (active_playlist, data->focused,
-     position - data->focused);
-
-    scroll_to (data, data->focused);
+    focus += aud_playlist_shift (active_playlist, focus, position - focus);
+    scroll_to (data, focus);
 }
 
 static void delete_selected (PlaylistData * data)
 {
-    gint shift = 0, count;
-
-    for (count = 0; count < data->focused; count ++)
-    {
-        if (aud_playlist_entry_get_selected (active_playlist, count))
-            shift --;
-    }
-
     aud_playlist_delete_selected (active_playlist);
-    active_length = aud_playlist_entry_count (active_playlist);
-    calc_layout (data);
 
-    data->focused = adjust_position (data, TRUE, shift);
-    select_single (data, TRUE, 0);
+    active_length = aud_playlist_entry_count (active_playlist);
+    gint focus = aud_playlist_get_focus (active_playlist);
+
+    if (focus != -1)
+    {
+        aud_playlist_entry_set_selected (active_playlist, focus, TRUE);
+        scroll_to (data, focus);
+    }
 }
 
 gboolean ui_skinned_playlist_key (GtkWidget * list, GdkEventKey * event)
@@ -551,35 +533,35 @@ gboolean ui_skinned_playlist_key (GtkWidget * list, GdkEventKey * event)
       case 0:
         switch (event->keyval)
         {
-          case GDK_Up:
+          case GDK_KEY_Up:
             select_single (data, TRUE, -1);
             break;
-          case GDK_Down:
+          case GDK_KEY_Down:
             select_single (data, TRUE, 1);
             break;
-          case GDK_Page_Up:
+          case GDK_KEY_Page_Up:
             select_single (data, TRUE, - data->rows);
             break;
-          case GDK_Page_Down:
+          case GDK_KEY_Page_Down:
             select_single (data, TRUE, data->rows);
             break;
-          case GDK_Home:
+          case GDK_KEY_Home:
             select_single (data, FALSE, 0);
             break;
-          case GDK_End:
+          case GDK_KEY_End:
             select_single (data, FALSE, active_length - 1);
             break;
-          case GDK_Return:
+          case GDK_KEY_Return:
             select_single (data, TRUE, 0);
-            aud_playlist_set_playing (active_playlist);
-            aud_playlist_set_position (active_playlist, data->focused);
-            aud_drct_play ();
+            aud_playlist_set_position (active_playlist,
+             aud_playlist_get_focus (active_playlist));
+            aud_drct_play_playlist (active_playlist);
             break;
-          case GDK_Escape:
+          case GDK_KEY_Escape:
             select_single (data, FALSE, aud_playlist_get_position
              (active_playlist));
             break;
-          case GDK_Delete:
+          case GDK_KEY_Delete:
             delete_selected (data);
             break;
           default:
@@ -589,22 +571,22 @@ gboolean ui_skinned_playlist_key (GtkWidget * list, GdkEventKey * event)
       case GDK_SHIFT_MASK:
         switch (event->keyval)
         {
-          case GDK_Up:
+          case GDK_KEY_Up:
             select_extend (data, TRUE, -1);
             break;
-          case GDK_Down:
+          case GDK_KEY_Down:
             select_extend (data, TRUE, 1);
             break;
-          case GDK_Page_Up:
+          case GDK_KEY_Page_Up:
             select_extend (data, TRUE, -data->rows);
             break;
-          case GDK_Page_Down:
+          case GDK_KEY_Page_Down:
             select_extend (data, TRUE, data->rows);
             break;
-          case GDK_Home:
+          case GDK_KEY_Home:
             select_extend (data, FALSE, 0);
             break;
-          case GDK_End:
+          case GDK_KEY_End:
             select_extend (data, FALSE, active_length - 1);
             break;
           default:
@@ -614,25 +596,25 @@ gboolean ui_skinned_playlist_key (GtkWidget * list, GdkEventKey * event)
       case GDK_CONTROL_MASK:
         switch (event->keyval)
         {
-          case GDK_space:
+          case GDK_KEY_space:
             select_toggle (data, TRUE, 0);
             break;
-          case GDK_Up:
+          case GDK_KEY_Up:
             select_slide (data, TRUE, -1);
             break;
-          case GDK_Down:
+          case GDK_KEY_Down:
             select_slide (data, TRUE, 1);
             break;
-          case GDK_Page_Up:
+          case GDK_KEY_Page_Up:
             select_slide (data, TRUE, -data->rows);
             break;
-          case GDK_Page_Down:
+          case GDK_KEY_Page_Down:
             select_slide (data, TRUE, data->rows);
             break;
-          case GDK_Home:
+          case GDK_KEY_Home:
             select_slide (data, FALSE, 0);
             break;
-          case GDK_End:
+          case GDK_KEY_End:
             select_slide (data, FALSE, active_length - 1);
             break;
           default:
@@ -642,22 +624,22 @@ gboolean ui_skinned_playlist_key (GtkWidget * list, GdkEventKey * event)
       case GDK_MOD1_MASK:
         switch (event->keyval)
         {
-          case GDK_Up:
+          case GDK_KEY_Up:
             select_move (data, TRUE, -1);
             break;
-          case GDK_Down:
+          case GDK_KEY_Down:
             select_move (data, TRUE, 1);
             break;
-          case GDK_Page_Up:
+          case GDK_KEY_Page_Up:
             select_move (data, TRUE, -data->rows);
             break;
-          case GDK_Page_Down:
+          case GDK_KEY_Page_Down:
             select_move (data, TRUE, data->rows);
             break;
-          case GDK_Home:
+          case GDK_KEY_Home:
             select_move (data, FALSE, 0);
             break;
-          case GDK_End:
+          case GDK_KEY_End:
             select_move (data, FALSE, active_length - 1);
             break;
           default:
@@ -672,15 +654,13 @@ gboolean ui_skinned_playlist_key (GtkWidget * list, GdkEventKey * event)
     return TRUE;
 }
 
-void ui_skinned_playlist_row_info (GtkWidget * list, gint * rows, gint * first,
- gint * focused)
+void ui_skinned_playlist_row_info (GtkWidget * list, gint * rows, gint * first)
 {
     PlaylistData * data = g_object_get_data ((GObject *) list, "playlistdata");
     g_return_if_fail (data);
 
     * rows = data->rows;
     * first = data->first;
-    * focused = data->focused;
 }
 
 void ui_skinned_playlist_scroll_to (GtkWidget * list, gint row)
@@ -704,7 +684,7 @@ void ui_skinned_playlist_set_focused (GtkWidget * list, gint row)
     g_return_if_fail (data);
 
     cancel_all (list, data);
-    data->focused = row;
+    aud_playlist_set_focus (active_playlist, row);
     scroll_to (data, row);
 
     gtk_widget_queue_draw (list);
@@ -812,13 +792,13 @@ static gboolean playlist_button_press (GtkWidget * list, GdkEventButton * event)
 
         break;
       case GDK_2BUTTON_PRESS:
-        if (event->button != 1 || state || position == -1 || position ==
-         active_length)
+        if (event->button != 1 || state || position == active_length)
             return TRUE;
 
-        aud_playlist_set_playing (active_playlist);
-        aud_playlist_set_position (active_playlist, position);
-        aud_drct_play ();
+        if (position != -1)
+            aud_playlist_set_position (active_playlist, position);
+
+        aud_drct_play_playlist (active_playlist);
         break;
       default:
         return TRUE;
