@@ -25,7 +25,9 @@
 #include <audacious/drct.h>
 #include <audacious/i18n.h>
 #include <audacious/misc.h>
+#include <audacious/plugin.h>
 #include <audacious/plugins.h>
+#include <audacious/preferences.h>
 #include <libaudcore/hook.h>
 #include <libaudgui/libaudgui.h>
 #include <libaudgui/libaudgui-gtk.h>
@@ -43,6 +45,14 @@ static void si_smallmenu_show(gint x, gint y, guint button, guint32 time, gpoint
 static void si_smallmenu_recreate(GtkStatusIcon *);
 static void si_popup_hide(gpointer icon);
 
+static const char * const si_defaults[] = {
+ "scroll_action", "0", /* SI_CFG_SCROLL_ACTION_VOLUME */
+ "volume_delta", "5",
+ "disable_popup", "FALSE",
+ "close_to_tray", "FALSE",
+ "reverse_scroll", "FALSE",
+ NULL};
+
 static gboolean plugin_active = FALSE;
 static gboolean recreate_smallmenu = FALSE;
 
@@ -59,7 +69,7 @@ static GtkStatusIcon *si_create(void)
         icon = gtk_status_icon_new_from_icon_name("audacious");
     else
     {
-        gchar * path = g_strdup_printf ("%s/images/audacious_player.xpm",
+        gchar * path = g_strdup_printf ("%s/images/audacious.png",
          aud_get_path (AUD_PATH_DATA_DIR));
         icon = gtk_status_icon_new_from_file (path);
         g_free (path);
@@ -70,6 +80,9 @@ static GtkStatusIcon *si_create(void)
 
 static gboolean si_cb_btpress(GtkStatusIcon * icon, GdkEventButton * event, gpointer user_data)
 {
+    if (event->type != GDK_BUTTON_PRESS)
+        return FALSE;
+
     si_popup_timer_stop(icon);
     si_popup_hide(icon);
 
@@ -103,7 +116,7 @@ static gboolean si_cb_btpress(GtkStatusIcon * icon, GdkEventButton * event, gpoi
           break;
     }
 
-    return FALSE;
+    return TRUE;
 }
 
 static gboolean si_cb_btscroll(GtkStatusIcon * icon, GdkEventScroll * event, gpointer user_data)
@@ -112,10 +125,10 @@ static gboolean si_cb_btscroll(GtkStatusIcon * icon, GdkEventScroll * event, gpo
     {
       case GDK_SCROLL_UP:
       {
-          switch (si_cfg.scroll_action)
+          switch (aud_get_int ("statusicon", "scroll_action"))
           {
             case SI_CFG_SCROLL_ACTION_VOLUME:
-                si_volume_change(si_cfg.volume_delta);
+                si_volume_change (aud_get_int ("statusicon", "volume_delta"));
                 break;
             case SI_CFG_SCROLL_ACTION_SKIP:
                 si_playback_skip (aud_get_bool ("statusicon", "reverse_scroll") ? 1 : -1);
@@ -126,10 +139,10 @@ static gboolean si_cb_btscroll(GtkStatusIcon * icon, GdkEventScroll * event, gpo
 
       case GDK_SCROLL_DOWN:
       {
-          switch (si_cfg.scroll_action)
+          switch (aud_get_int ("statusicon", "scroll_action"))
           {
             case SI_CFG_SCROLL_ACTION_VOLUME:
-                si_volume_change(-si_cfg.volume_delta);
+                si_volume_change (-aud_get_int ("statusicon", "volume_delta"));
                 break;
             case SI_CFG_SCROLL_ACTION_SKIP:
                 si_playback_skip (aud_get_bool ("statusicon", "reverse_scroll") ? -1 : 1);
@@ -146,14 +159,12 @@ static gboolean si_cb_btscroll(GtkStatusIcon * icon, GdkEventScroll * event, gpo
 
 static gboolean si_popup_show(gpointer icon)
 {
-    GdkDisplay *display = gdk_display_get_default();
-    GdkScreen *screen = gdk_display_get_default_screen(display);
     GdkRectangle area;
     gint x, y;
     static gint count = 0;
 
-    gdk_display_get_pointer(display, &screen, &x, &y, NULL);
-    gtk_status_icon_get_geometry(icon, &screen, &area, NULL);
+    audgui_get_mouse_coords (NULL, & x, & y);
+    gtk_status_icon_get_geometry (icon, NULL, & area, NULL);
 
     if (x < area.x || x > area.x + area.width || y < area.y || y > area.y + area.width)
     {
@@ -217,7 +228,9 @@ static void si_popup_timer_stop(GtkStatusIcon * icon)
 
 static gboolean si_cb_tooltip(GtkStatusIcon * icon, gint x, gint y, gboolean keyboard_mode, GtkTooltip * tooltip, gpointer user_data)
 {
-    if (si_cfg.disable_popup)
+    GtkWidget *menu = g_object_get_data(G_OBJECT(icon), "smenu");
+
+    if (aud_get_bool("statusicon", "disable_popup") || gtk_widget_get_visible(menu))
         return FALSE;
 
     if (!POPUP_IS_ACTIVE && !TIMER_IS_ACTIVE)
@@ -237,7 +250,7 @@ static GtkWidget *si_smallmenu_create(void)
     GtkWidget *si_smenu = gtk_menu_new();
     GtkWidget *si_smenu_prev_item, *si_smenu_play_item, *si_smenu_pause_item;
     GtkWidget *si_smenu_stop_item, *si_smenu_next_item, *si_smenu_sep_item, *si_smenu_eject_item;
-    GtkWidget *si_smenu_quit_item;
+    GtkWidget *si_smenu_pref_item, *si_smenu_quit_item;
 
     si_smenu_eject_item = gtk_image_menu_item_new_from_stock(GTK_STOCK_OPEN, NULL);
     g_signal_connect_swapped(si_smenu_eject_item, "activate", G_CALLBACK(si_playback_ctrl), GINT_TO_POINTER(SI_PLAYBACK_CTRL_EJECT));
@@ -266,17 +279,17 @@ static GtkWidget *si_smallmenu_create(void)
     g_signal_connect_swapped(si_smenu_next_item, "activate", G_CALLBACK(si_playback_ctrl), GINT_TO_POINTER(SI_PLAYBACK_CTRL_NEXT));
     gtk_menu_shell_append(GTK_MENU_SHELL(si_smenu), si_smenu_next_item);
     gtk_widget_show(si_smenu_next_item);
-
-    if (si_cfg.rclick_menu == SI_CFG_RCLICK_MENU_SMALL2)
-    {
-        si_smenu_sep_item = gtk_separator_menu_item_new();
-        gtk_menu_shell_append(GTK_MENU_SHELL(si_smenu), si_smenu_sep_item);
-        gtk_widget_show(si_smenu_sep_item);
-        si_smenu_quit_item = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, NULL);
-        g_signal_connect_swapped(si_smenu_quit_item, "activate", G_CALLBACK(aud_drct_quit), NULL);
-        gtk_menu_shell_append(GTK_MENU_SHELL(si_smenu), si_smenu_quit_item);
-        gtk_widget_show(si_smenu_quit_item);
-    }
+    si_smenu_sep_item = gtk_separator_menu_item_new();
+    gtk_menu_shell_append(GTK_MENU_SHELL(si_smenu), si_smenu_sep_item);
+    gtk_widget_show(si_smenu_sep_item);
+    si_smenu_pref_item = gtk_image_menu_item_new_from_stock(GTK_STOCK_PREFERENCES, NULL);
+    g_signal_connect_swapped(si_smenu_pref_item, "activate", G_CALLBACK(aud_show_prefs_window), NULL);
+    gtk_menu_shell_append(GTK_MENU_SHELL(si_smenu), si_smenu_pref_item);
+    gtk_widget_show(si_smenu_pref_item);
+    si_smenu_quit_item = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, NULL);
+    g_signal_connect_swapped(si_smenu_quit_item, "activate", G_CALLBACK(aud_drct_quit), NULL);
+    gtk_menu_shell_append(GTK_MENU_SHELL(si_smenu), si_smenu_quit_item);
+    gtk_widget_show(si_smenu_quit_item);
 
     return si_smenu;
 }
@@ -294,7 +307,7 @@ static void si_window_close(gpointer data, gpointer user_data)
 {
     gboolean *handle = (gboolean*) data;
 
-    if (si_cfg.close_to_tray)
+    if (aud_get_bool ("statusicon", "close_to_tray"))
     {
         *handle = TRUE;
         aud_interface_show (FALSE);
@@ -358,8 +371,8 @@ static void si_enable(gboolean enable)
 
 static gboolean si_init (void)
 {
+    aud_config_set_defaults ("statusicon", si_defaults);
     plugin_active = TRUE;
-    si_cfg_load();
     si_enable(TRUE);
     return TRUE;
 }
@@ -371,191 +384,41 @@ void si_cleanup(void)
 
     plugin_active = FALSE;
     si_enable(FALSE);
-    si_cfg_save();
 }
 
-void si_about(void)
-{
-    static GtkWidget *about_dlg = NULL;
+static const char si_about[] =
+ N_("Status Icon Plugin\n\n"
+    "Copyright 2005-2007 Giacomo Lozito <james@develia.org>\n"
+    "Copyright 2010 Michał Lipski <tallica@o2.pl>\n\n"
+    "This plugin provides a status icon, placed in\n"
+    "the system tray area of the window manager.");
 
-    if (about_dlg != NULL)
-    {
-        gtk_window_present(GTK_WINDOW(about_dlg));
-        return;
-    }
+static const PreferencesWidget si_widgets[] = {
+ {WIDGET_LABEL, N_("<b>Mouse Scroll Action</b>")},
+ {WIDGET_RADIO_BTN, N_("Change volume"),
+  .cfg_type = VALUE_INT, .csect = "statusicon", .cname = "scroll_action",
+  .data = {.radio_btn = {SI_CFG_SCROLL_ACTION_VOLUME}}},
+ {WIDGET_RADIO_BTN, N_("Change playing song"),
+  .cfg_type = VALUE_INT, .csect = "statusicon", .cname = "scroll_action",
+  .data = {.radio_btn = {SI_CFG_SCROLL_ACTION_SKIP}}},
+ {WIDGET_LABEL, N_("<b>Other Settings</b>")},
+ {WIDGET_CHK_BTN, N_("Disable the popup window"),
+  .cfg_type = VALUE_BOOLEAN, .csect = "statusicon", .cname = "disable_popup"},
+ {WIDGET_CHK_BTN, N_("Close to the system tray"),
+  .cfg_type = VALUE_BOOLEAN, .csect = "statusicon", .cname = "close_to_tray"},
+ {WIDGET_CHK_BTN, N_("Advance in playlist when scrolling upward"),
+  .cfg_type = VALUE_BOOLEAN, .csect = "statusicon", .cname = "reverse_scroll"}};
 
-    audgui_simple_message(&about_dlg, GTK_MESSAGE_INFO, _("About Status Icon Plugin"),
-                        _("Status Icon Plugin\n\n"
-                          "Copyright 2005-2007 Giacomo Lozito <james@develia.org>\n"
-                          "Copyright 2010 Michał Lipski <tallica@o2.pl>\n\n"
-                          "This plugin provides a status icon, placed in\n"
-                          "the system tray area of the window manager.\n"));
-}
-
-static GtkWidget *prefs_disable_popup_chkbtn;
-static GtkWidget *prefs_close_to_tray_chkbtn;
-static GtkWidget * reverse_scroll_toggle;
-
-void si_prefs_cb_commit(gpointer prefs_win)
-{
-    GSList *list = g_object_get_data(G_OBJECT(prefs_win), "rcm_grp");
-    while (list != NULL)
-    {
-        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(list->data)) == TRUE)
-        {
-            si_cfg.rclick_menu = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(list->data), "val"));
-            break;
-        }
-        list = g_slist_next(list);
-    }
-
-    list = g_object_get_data(G_OBJECT(prefs_win), "msa_grp");
-    while (list != NULL)
-    {
-        if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(list->data)) == TRUE)
-        {
-            si_cfg.scroll_action = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(list->data), "val"));
-            break;
-        }
-        list = g_slist_next(list);
-    }
-
-    si_cfg.disable_popup = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_disable_popup_chkbtn));
-    si_cfg.close_to_tray = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_close_to_tray_chkbtn));
-    aud_set_bool ("statusicon", "reverse_scroll", gtk_toggle_button_get_active
-     ((GtkToggleButton *) reverse_scroll_toggle));
-
-    si_cfg_save();
-
-    /* request the recreation of status icon small-menu if necessary */
-    recreate_smallmenu = TRUE;
-
-    gtk_widget_destroy(GTK_WIDGET(prefs_win));
-}
-
-
-void si_config(void)
-{
-    static GtkWidget *prefs_win = NULL;
-    GtkWidget *prefs_vbox;
-    GtkWidget *prefs_rclick_frame, *prefs_rclick_vbox;
-    GtkWidget *prefs_rclick_smallmenu1_rbt, *prefs_rclick_smallmenu2_rbt;
-    GtkWidget *prefs_scroll_frame, *prefs_scroll_vbox;
-    GtkWidget *prefs_other_frame, *prefs_other_vbox;
-    GtkWidget *prefs_scroll_vol_rbt, *prefs_scroll_skip_rbt;
-    GtkWidget *prefs_bbar_bbox;
-    GtkWidget *prefs_bbar_bt_ok, *prefs_bbar_bt_cancel;
-    GdkGeometry prefs_win_hints;
-
-    if (prefs_win != NULL)
-    {
-        gtk_window_present(GTK_WINDOW(prefs_win));
-        return;
-    }
-
-    prefs_win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_type_hint(GTK_WINDOW(prefs_win), GDK_WINDOW_TYPE_HINT_DIALOG);
-    gtk_window_set_position(GTK_WINDOW(prefs_win), GTK_WIN_POS_CENTER);
-    gtk_window_set_title(GTK_WINDOW(prefs_win), _("Status Icon Plugin - Preferences"));
-    gtk_container_set_border_width(GTK_CONTAINER(prefs_win), 10);
-    prefs_win_hints.min_width = 320;
-    prefs_win_hints.min_height = -1;
-    gtk_window_set_geometry_hints(GTK_WINDOW(prefs_win), GTK_WIDGET(prefs_win), &prefs_win_hints, GDK_HINT_MIN_SIZE);
-    g_signal_connect(G_OBJECT(prefs_win), "destroy", G_CALLBACK(gtk_widget_destroyed), &prefs_win);
-
-    prefs_vbox = gtk_vbox_new(FALSE, 0);
-    gtk_container_add(GTK_CONTAINER(prefs_win), prefs_vbox);
-
-    prefs_rclick_frame = gtk_frame_new(_("Right-Click Menu"));
-    prefs_rclick_vbox = gtk_vbox_new(TRUE, 0);
-    gtk_container_set_border_width(GTK_CONTAINER(prefs_rclick_vbox), 6);
-    gtk_container_add(GTK_CONTAINER(prefs_rclick_frame), prefs_rclick_vbox);
-    prefs_rclick_smallmenu1_rbt = gtk_radio_button_new_with_label (NULL,
-     _("Small playback menu #1"));
-    g_object_set_data(G_OBJECT(prefs_rclick_smallmenu1_rbt), "val", GINT_TO_POINTER(SI_CFG_RCLICK_MENU_SMALL1));
-    prefs_rclick_smallmenu2_rbt = gtk_radio_button_new_with_label_from_widget
-     ((GtkRadioButton *) prefs_rclick_smallmenu1_rbt, _("Small playback menu #2"));
-    g_object_set_data(G_OBJECT(prefs_rclick_smallmenu2_rbt), "val", GINT_TO_POINTER(SI_CFG_RCLICK_MENU_SMALL2));
-    g_object_set_data(G_OBJECT(prefs_win), "rcm_grp", gtk_radio_button_get_group(GTK_RADIO_BUTTON(prefs_rclick_smallmenu1_rbt)));
-    switch (si_cfg.rclick_menu)
-    {
-      case SI_CFG_RCLICK_MENU_SMALL1:
-          gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_rclick_smallmenu1_rbt), TRUE);
-          break;
-      case SI_CFG_RCLICK_MENU_SMALL2:
-          gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_rclick_smallmenu2_rbt), TRUE);
-          break;
-    }
-    gtk_box_pack_start(GTK_BOX(prefs_rclick_vbox), prefs_rclick_smallmenu1_rbt, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(prefs_rclick_vbox), prefs_rclick_smallmenu2_rbt, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(prefs_vbox), prefs_rclick_frame, TRUE, TRUE, 0);
-
-    prefs_scroll_frame = gtk_frame_new(_("Mouse Scroll Action"));
-    prefs_scroll_vbox = gtk_vbox_new(TRUE, 0);
-    gtk_container_set_border_width(GTK_CONTAINER(prefs_scroll_vbox), 6);
-    gtk_container_add(GTK_CONTAINER(prefs_scroll_frame), prefs_scroll_vbox);
-    prefs_scroll_vol_rbt = gtk_radio_button_new_with_label(NULL, _("Change volume"));
-    g_object_set_data(G_OBJECT(prefs_scroll_vol_rbt), "val", GINT_TO_POINTER(SI_CFG_SCROLL_ACTION_VOLUME));
-    prefs_scroll_skip_rbt = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(prefs_scroll_vol_rbt), _("Change playing song"));
-    g_object_set_data(G_OBJECT(prefs_scroll_skip_rbt), "val", GINT_TO_POINTER(SI_CFG_SCROLL_ACTION_SKIP));
-    g_object_set_data(G_OBJECT(prefs_win), "msa_grp", gtk_radio_button_get_group(GTK_RADIO_BUTTON(prefs_scroll_skip_rbt)));
-
-    if (si_cfg.scroll_action == SI_CFG_SCROLL_ACTION_VOLUME)
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_scroll_vol_rbt), TRUE);
-    else
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_scroll_skip_rbt), TRUE);
-
-    gtk_box_pack_start(GTK_BOX(prefs_scroll_vbox), prefs_scroll_vol_rbt, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(prefs_scroll_vbox), prefs_scroll_skip_rbt, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(prefs_vbox), prefs_scroll_frame, TRUE, TRUE, 0);
-
-    prefs_other_frame = gtk_frame_new(_("Other settings"));
-    prefs_other_vbox = gtk_vbox_new(TRUE, 0);
-    gtk_container_set_border_width(GTK_CONTAINER(prefs_other_vbox), 6);
-    gtk_container_add(GTK_CONTAINER(prefs_other_frame), prefs_other_vbox);
-
-    prefs_disable_popup_chkbtn = gtk_check_button_new_with_label(_("Disable the popup window"));
-
-    if (si_cfg.disable_popup)
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_disable_popup_chkbtn), TRUE);
-
-    gtk_box_pack_start(GTK_BOX(prefs_other_vbox), prefs_disable_popup_chkbtn, TRUE, TRUE, 0);
-
-    prefs_close_to_tray_chkbtn = gtk_check_button_new_with_label(_("Close to the notification area (system tray)"));
-
-    if (si_cfg.close_to_tray)
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_close_to_tray_chkbtn), TRUE);
-
-    gtk_box_pack_start(GTK_BOX(prefs_other_vbox), prefs_close_to_tray_chkbtn, TRUE, TRUE, 0);
-
-    reverse_scroll_toggle = gtk_check_button_new_with_label
-     (_("Advance in playlist when scrolling upward"));
-    gtk_toggle_button_set_active ((GtkToggleButton *) reverse_scroll_toggle,
-     aud_get_bool ("statusicon", "reverse_scroll"));
-    gtk_box_pack_start ((GtkBox *) prefs_other_vbox, reverse_scroll_toggle, TRUE, TRUE, 0);
-
-    gtk_box_pack_start(GTK_BOX(prefs_vbox), prefs_other_frame, TRUE, TRUE, 0);
-
-    /* horizontal separator and buttons */
-    gtk_box_pack_start(GTK_BOX(prefs_vbox), gtk_hseparator_new(), FALSE, FALSE, 4);
-    prefs_bbar_bbox = gtk_hbutton_box_new();
-    gtk_button_box_set_layout(GTK_BUTTON_BOX(prefs_bbar_bbox), GTK_BUTTONBOX_END);
-    prefs_bbar_bt_cancel = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-    g_signal_connect_swapped(G_OBJECT(prefs_bbar_bt_cancel), "clicked", G_CALLBACK(gtk_widget_destroy), prefs_win);
-    gtk_container_add(GTK_CONTAINER(prefs_bbar_bbox), prefs_bbar_bt_cancel);
-    prefs_bbar_bt_ok = gtk_button_new_from_stock(GTK_STOCK_OK);
-    gtk_container_add(GTK_CONTAINER(prefs_bbar_bbox), prefs_bbar_bt_ok);
-    g_signal_connect_swapped(G_OBJECT(prefs_bbar_bt_ok), "clicked", G_CALLBACK(si_prefs_cb_commit), prefs_win);
-    gtk_box_pack_start(GTK_BOX(prefs_vbox), prefs_bbar_bbox, FALSE, FALSE, 0);
-
-    gtk_widget_show_all(prefs_win);
-}
+static const PluginPreferences si_prefs = {
+ .widgets = si_widgets,
+ .n_widgets = G_N_ELEMENTS (si_widgets)};
 
 AUD_GENERAL_PLUGIN
 (
-    .name = "Status Icon",
+    .name = N_("Status Icon"),
+    .domain = PACKAGE,
+    .about_text = si_about,
+    .prefs = & si_prefs,
     .init = si_init,
     .cleanup = si_cleanup,
-    .about = si_about,
-    .configure = si_config
 )
