@@ -2,6 +2,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 
 #include "desmume/MMU.h"
 #include "desmume/armcpu.h"
@@ -10,7 +11,6 @@
 #include "desmume/cp15.h"
 
 #include <zlib.h>
-#include <glib.h>
 #include "tagget.h"
 #include "vio2sf.h"
 
