@@ -31,6 +31,7 @@
 #include <libxml/xpathInternals.h>
 #include <libxml/uri.h>
 
+#include <audacious/i18n.h>
 #include <audacious/plugin.h>
 
 #define XSPF_ROOT_NODE_NAME "playlist"
@@ -436,7 +437,8 @@ static const gchar * const xspf_exts[] = {"xspf", NULL};
 
 AUD_PLAYLIST_PLUGIN
 (
- .name = "XML Shareable Playlist Format",
+ .name = N_("XML Shareable Playlists (XSPF)"),
+ .domain = PACKAGE,
  .extensions = xspf_exts,
  .load = xspf_playlist_load,
  .save = xspf_playlist_save
